@@ -1,14 +1,15 @@
 package MySQL::Easy;
 
-# $Id: Easy.pm,v 1.8 2002/01/17 17:55:22 jettero Exp $
+# $Id: Easy.pm,v 1.13 2002/02/26 15:16:13 jettero Exp $
 # vi:fdm=marker fdl=0:
 
 use strict;
 use warnings;
+use Carp;
 
 use DBI;
 
-our $VERSION = "0.99b";
+our $VERSION = "1.0b";
 
 return 1;
 
@@ -29,7 +30,12 @@ sub new {
 sub do {
     my $this = shift; return unless @_;
 
-    $this->ready(shift)->execute(@_);
+    my $e = $SIG{__WARN__}; $SIG{__WARN__} = sub {};
+    my $r = $this->ready(shift)->execute(@_) or croak $this->errstr;
+
+    $SIG{__WARN__} = $e;
+
+    return $r;
 }
 # }}}
 # lock {{{
@@ -77,6 +83,19 @@ sub errstr {
     return $this->handle->errstr;
 }
 # }}}
+# last_insert_id {{{
+sub last_insert_id {
+    my $this = shift;
+
+    return $this->firstcol("select last_insert_id()")->[0];
+}
+# }}}
+
+sub DESTROY {
+    my $this = shift;
+
+    $this->{dbh}->disconnect if $this->{dbh};
+}
 
 # handle {{{
 sub handle {
@@ -90,7 +109,7 @@ sub handle {
         $this->{trace} =           0 unless $this->{trace};
 
         $this->{dbh} = DBI->connect("DBI:mysql:$this->{dbase}:$this->{host}", $this->{user}, $this->{pass});
-        $this->{dbh}->trace($this->{trace});
+        $this->{dbh}->trace($this->{trace}) if $this->{dbh};
     }
 
     return $this->{dbh};
@@ -104,9 +123,10 @@ sub unp {
 
     open PASS, "$ENV{HOME}/.my.cnf" or die "$!";
 
-    while(<PASS>) {
-        $user = $1 if /user\s*=\s*(.+)/;
-        $pass = $1 if /password\s*=\s*(.+)/;
+    my $l;
+    while($l = <PASS>) {
+        $user = $1 if $l =~ m/user\s*=\s*(.+)/;
+        $pass = $1 if $l =~ m/password\s*=\s*(.+)/;
 
         last if($user and $pass);
     }
@@ -186,6 +206,9 @@ MySQL::Easy - Perl extension to make your base code kinda pretty.
        # You know, print "val: $_\n" for @$arr;
        # very handy...
 
+   $id = $dbo->last_insert_id;
+       # self explainatory?
+
    $dbo->trace(1); $dbo->do("sql"); $dbo->trace(0);
        # turns the DBI trace on and off.
 
